# tket-eccs

[![pypi][]](https://pypi.org/project/tket-eccs/)
[![codecov][]](https://codecov.io/gh/CQCL/tket2)
[![py-version][]](https://pypi.org/project/tket--eccs/)

  [codecov]: https://img.shields.io/codecov/c/gh/CQCL/tket2?logo=codecov
  [py-version]: https://img.shields.io/pypi/pyversions/tket-eccs
  [pypi]: https://img.shields.io/pypi/v/tket-eccs

This is an auxiliary Python package containing compiler rewrite sets used for `tket`'s optimisation passes.

This package is intended to be used as an internal dependency for `tket`.
See https://pypi.org/project/tket/ for the main package.


## Install

TKET-eccs can be installed via `pip`.

```sh
pip install tket_eccs
```

## Development

See [DEVELOPMENT.md] information on how to develop and contribute to this package.

  [DEVELOPMENT.md]: https://github.com/CQCL/tket2/blob/main/DEVELOPMENT.md


## License

This project is licensed under Apache License, Version 2.0 ([LICENCE][] or http://www.apache.org/licenses/LICENSE-2.0).

  [LICENCE]: https://github.com/CQCL/tket2/blob/main/LICENCE
